@@ -103,7 +103,7 @@ NB_CORE void fail(const char *fmt, ...) noexcept;
 NB_CORE void raise_next_overload_if_null(void *p);
 
 /// Raise nanobind::cast_error
-[[noreturn]] NB_CORE void raise_cast_error();
+[[noreturn]] NB_CORE void raise_python_or_cast_error();
 
 // ========================================================================
 
@@ -161,6 +161,9 @@ NB_CORE PyObject *tuple_from_obj(PyObject *o);
 /// Convert a Python object into a Python set
 NB_CORE PyObject *set_from_obj(PyObject *o);
 
+/// Convert a Python object into a Python frozenset
+NB_CORE PyObject *frozenset_from_obj(PyObject *o);
+
 // ========================================================================
 
 /// Get an object attribute or raise an exception
